klastorin <- function(phy)
    .Defunct(msg = '\'klastorin\' has been removed from ape,
    see help("ape-defunct") for details.')

mlphylo <- function(...)
    .Defunct(msg = '\'mlphylo\' has been removed from ape,
    see help("ape-defunct") for details.')

DNAmodel <- function(...)
    .Defunct(msg = '\'DNAmodel\' has been removed from ape,
    see help("ape-defunct") for details.')

sh.test <- function(...)
    .Defunct(msg = '\'sh.test\' has been removed from ape,
    see help("ape-defunct") for details.')

evolve.phylo <- function(phy, value, var)
    .Defunct(msg = '\'evolve.phylo\' has been removed from ape,
    see help("ape-defunct") for details.')

plot.ancestral <- function(...)
    .Defunct(msg = '\'plot.ancestral\' has been removed from ape,
    see help("ape-defunct") for details.')

chronogram <- function(...)
    .Defunct(msg = '\'chronogram\' has been removed from ape,
    see help("ape-defunct") for details.')

ratogram <- function(...)
    .Defunct(msg = '\'ratogram\' has been removed from ape,
    see help("ape-defunct") for details.')

NPRS.criterion <- function(...)
    .Defunct(msg = '\'NPRS.criterion\' has been removed from ape,
    see help("ape-defunct") for details.')
